// Copyright (c) 2022-2023 VMware Carbon Black, all rights reserved

package main

import (
	"encoding/json"
	"fmt"
	"net/http"
	"time"

	"hello-api/internal/logger"

	"gitlab.bit9.local/psc/ems/hinting/pkg/hints"
	"gitlab.bit9.local/psc/ems/hinting/pkg/hints/hinttype"
)

var (
	MockUpdateTime = time.UnixMilli(1672574400000) // Sunday, January 1, 2023 12:00:00 GMT
	MockQueryTime  = time.UnixMilli(1659960000000) // Monday, August 8, 2022 12:00:00 GMT
	MockHints      = hints.NewHintResult(hinttype.NEW_CONFIG_DATA, hinttype.NEW_POLICY).Hints.ToIntArray()
)

// This simple server is designed to respond with a canned hinting response for use by the hello service.
//
//goland:noinspection GoUnhandledErrorResult
func main() {
	hintResult := hints.NewHintResult(hinttype.NEW_CONFIG_DATA, hinttype.NEW_POLICY)

	hintResult.LastUpdateTime = &MockUpdateTime
	hintResult.LastLiveQueryTime = &MockQueryTime
	hintingServiceResponseBytes, _ := json.Marshal(hintResult)

	hintingService := http.HandlerFunc(func(w http.ResponseWriter, R *http.Request) {
		logger.BaseLogger().Info(fmt.Sprintf("Header: %v", R.Header))
		_, _ = w.Write(hintingServiceResponseBytes) // Should be no errors here for this fake service
	})

	_ = http.ListenAndServe("0.0.0.0:31337", hintingService) //nolint:gosec // Used only for testing, not external
}
